# idc-index-data

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

[![Discourse Forum][discourse-forum-badge]][discourse-forum-link]

<!-- SPHINX-START -->

## About

`idc-index-data` is a Python package providing the index to query and download
data hosted by the
[NCI Imaging Data Commons (IDC)](https://imaging.datacommons.cancer.gov).

## Usage

This Python package bundles the `idc_index.csv.zip` archive and is intended to
be used by the [idc-index](https://pypi.org/project/idc-index/) Python package.

## Acknowledgment

This software is maintained by the IDC team, which has been funded in whole or
in part with Federal funds from the NCI, NIH, under task order no. HHSN26110071
under contract no. HHSN261201500003l.

If this package helped your research, we would appreciate if you could cite IDC
paper below.

> Fedorov, A., Longabaugh, W. J. R., Pot, D., Clunie, D. A., Pieper, S. D.,
> Gibbs, D. L., Bridge, C., Herrmann, M. D., Homeyer, A., Lewis, R., Aerts, H.
> J. W., Krishnaswamy, D., Thiriveedhi, V. K., Ciausu, C., Schacherer, D. P.,
> Bontempi, D., Pihl, T., Wagner, U., Farahani, K., Kim, E. & Kikinis, R.
> _National Cancer Institute Imaging Data Commons: Toward Transparency,
> Reproducibility, and Scalability in Imaging Artificial Intelligence_.
> RadioGraphics (2023). https://doi.org/10.1148/rg.230180

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/ImagingDataCommons/idc-index-data/workflows/CI/badge.svg
[actions-link]:             https://github.com/ImagingDataCommons/idc-index-data/actions
[discourse-forum-badge]: https://img.shields.io/discourse/https/discourse.canceridc.dev/status.svg
[discourse-forum-link]:  https://discourse.canceridc.dev/
[pypi-link]:                https://pypi.org/project/idc-index-data/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/idc-index-data
[pypi-version]:             https://img.shields.io/pypi/v/idc-index-data
[rtd-badge]:                https://readthedocs.org/projects/idc-index-data/badge/?version=latest
[rtd-link]:                 https://idc-index-data.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->
